@@ -3,7 +3,7 @@ modavg.shrink <-
            nobs = NULL, uncond.se = "revised", parm.type = NULL){
 
     mod.avg.shrink <- NULL
-    known <- rep(0, 8) #create an identifier of class type other than lm, glm, multinom, polr, lme, gls, or mer
+    known <- rep(0, 9) #create an identifier of class type other than lm, glm, multinom, polr, lme, gls, mer, unmarked, coxph
     ##extract classes
     mod.class <- unlist(lapply(X = cand.set, FUN = class))
     ##check if all are identical
@@ -66,17 +66,26 @@ modavg.shrink <-
       known[7] <- 1
     }
     
-    
-    ##warn if models are from a mixture of model classes
-    if(identical(sort(check.class), c("lm", "lme"))) {
-      stop(cat("Function not appropriate for mixture of object classes:", "\n",
-               "avoid mixing objects of classes lm and lme", "\n"))
+
+    ##determine if coxph
+    if(identical(check.class, "coxph") || identical(check.class, c("coxph.null", "coxph"))) {
+      mod.avg.shrink <- modavg.shrink.coxph(cand.set = cand.set, parm = parm, modnames = modnames, conf.level = conf.level,
+                              second.ord = second.ord, nobs = nobs, uncond.se = uncond.se)
       known[8] <- 1
     }
 
 
+    
+    ##warn if models are from a mixture of model classes
+    if(identical(sort(check.class), c("lm", "lme"))) {
+      stop("\nFunction not appropriate for mixture of object classes:", "\n",
+               "avoid mixing objects of classes lm and lme", "\n")
+      known[9] <- 1
+    }
+
+
     ##warn if class is neither lm, glm, multinom, polr, lme, gls nor mer
-    if(sum(known) < 1) {stop("Function not yet defined for this object class\n")}
+    if(sum(known) < 1) {stop("\nFunction not yet defined for this object class\n")}
 
 
       
