@@ -1,7 +1,7 @@
 modavgpred <- function(cand.set, modnames, newdata, type = "response", c.hat = 1,
                        gamdisp = NULL, second.ord = TRUE, nobs = NULL, uncond.se = "revised", parm.type = NULL){
   results <- NULL
-  known <- rep(0, 5) #create an identifier of class type for lm, glm, lme, mer, and unmarked
+  known <- rep(0, 5) #create an identifier of class type for lm, glm, lme, mer, unmarked,
   ##extract classes
   mod.class <- unlist(lapply(X = cand.set, FUN = class))
   ##check if all are identical
@@ -10,15 +10,15 @@ modavgpred <- function(cand.set, modnames, newdata, type = "response", c.hat = 1
   ##determine if lm or glm
   if(identical(check.class, "lm") || identical(check.class, c("glm", "lm"))) {
     results <- modavgpred.glm(cand.set = cand.set, modnames = modnames, newdata = newdata,
-                          type = type, c.hat = c.hat, gamdisp = gamdisp, second.ord = second.ord, 
-                          nobs = nobs, uncond.se = uncond.se)
+                              type = type, c.hat = c.hat, gamdisp = gamdisp, second.ord = second.ord, 
+                              nobs = nobs, uncond.se = uncond.se)
     known[1] <- 1
   }
 
   ##determine if lme
   if(identical(check.class, "lme"))  {
     results <- modavgpred.lme(cand.set = cand.set, modnames = modnames, newdata = newdata,
-                          second.ord = second.ord, nobs = nobs, uncond.se = uncond.se)
+                              second.ord = second.ord, nobs = nobs, uncond.se = uncond.se)
     known[2] <- 1
   }
 
@@ -27,12 +27,12 @@ modavgpred <- function(cand.set, modnames, newdata, type = "response", c.hat = 1
     results <- modavgpred.mer(cand.set = cand.set, modnames = modnames, newdata = newdata,
                               type = type, c.hat = c.hat, second.ord = second.ord, nobs = nobs,
                               uncond.se = uncond.se)
-      known[3] <- 1
-    }
+    known[3] <- 1
+  }
 
   ##determine if unmarked
   unmarked.class <- c("unmarkedFitOccu", "unmarkedFitColExt", "unmarkedFitOccuRN", "unmarkedFitPCount", "unmarkedFitPCO",
-                                              "unmarkedFitDS", "unmarkedFitGDS")
+                      "unmarkedFitDS", "unmarkedFitGDS")
   if(any(sapply(unmarked.class, FUN = function(i) identical(i, check.class)))) {
     results <- modavgpred.unmarked(cand.set = cand.set, modnames = modnames, newdata = newdata,
                                    type = type, c.hat = c.hat, second.ord = second.ord,
@@ -43,12 +43,13 @@ modavgpred <- function(cand.set, modnames, newdata, type = "response", c.hat = 1
   ##determine if gls
   if(identical(check.class, "gls"))  {
     results <- modavgpred.gls(cand.set = cand.set, modnames = modnames, newdata = newdata,
-                          second.ord = second.ord, nobs = nobs, uncond.se = uncond.se)
+                              second.ord = second.ord, nobs = nobs, uncond.se = uncond.se)
     known[5] <- 1
   }
-  
-  ##warn if class is neither lm, glm, nor lme
-  if(sum(known) < 1) {stop("Function not yet defined for this object class")}
+
+    
+  ##warn if class is neither lm, glm, lme, unmarked, nor coxph
+  if(sum(known) < 1) {stop("\nFunction not yet defined for this object class")}
   
   return(results)
 }
@@ -62,7 +63,7 @@ modavgpred.glm <-
 function(cand.set, modnames, newdata, type = "response", c.hat = 1, gamdisp = NULL, second.ord = TRUE,
          nobs = NULL, uncond.se = "revised") {
   ##newdata is data frame with exact structure of the original data frame (same variable names and type)
-  if(type == "terms") {stop("The terms argument is not defined for this function")}
+  if(type == "terms") {stop("\nThe terms argument is not defined for this function\n")}
 
   ##check family of glm to avoid problems when requesting predictions with argument 'dispersion'
   fam.type <- unlist(lapply(cand.set, FUN=function(i) family(i)$family))
@@ -76,7 +77,7 @@ function(cand.set, modnames, newdata, type = "response", c.hat = 1, gamdisp = NU
 ##############################
   if(c.hat > 1) {dispersion <- c.hat }
   if(!is.null(gamdisp)) {dispersion <- gamdisp}
-  if(c.hat > 1 && !is.null(gamdisp)) {stop("You cannot specify values for both \'c.hat\' and \'gamdisp\'")}
+  if(c.hat > 1 && !is.null(gamdisp)) {stop("\nYou cannot specify values for both \'c.hat\' and \'gamdisp\'\n")}
   ##dispersion is the dispersion parameter - this influences the SE's (to specify dispersion parameter for either overdispersed Poisson or Gamma glm)
   ##type enables to specify either "response" (original scale = point estimate) or "link" (linear predictor)
   
@@ -90,8 +91,8 @@ function(cand.set, modnames, newdata, type = "response", c.hat = 1, gamdisp = NU
   if(identical(type, "link")) {
     check.link <- unlist(lapply(X = cand.set, FUN = function(i) i$family$link))
     unique.link <- unique(x = check.link)
-    if(length(unique.link) > 1) {stop(cat("It is not appropriate to compute a model averaged beta estimate\n",
-                                          "with different link functions\n"))}
+    if(length(unique.link) > 1) {stop("\nIt is not appropriate to compute a model averaged beta estimate\n",
+                                          "with different link functions\n")}
   }
 
  
@@ -103,7 +104,7 @@ function(cand.set, modnames, newdata, type = "response", c.hat = 1, gamdisp = NU
     ##correct SE's for estimates of gamma regressions when gamdisp is specified
     if(any(gam1) == TRUE)  {
       ##check for specification of gamdisp argument
-      if(is.null(gamdisp)) stop("You must specify a gamma dispersion parameter with gamma generalized linear models\n")
+      if(is.null(gamdisp)) stop("\nYou must specify a gamma dispersion parameter with gamma generalized linear models\n")
     }
   
     
@@ -267,7 +268,7 @@ function(cand.set, modnames, newdata, type = "response", c.hat = 1, gamdisp = NU
     class(Mod.pred.list) <- c("modavgpred", "list")
     return(Mod.pred.list)
 
-  } else {stop("This function is only appropriate with either \'lm\' or \'glm\' classes\n")}
+  } else {stop("\nThis function is only appropriate with either \'lm\' or \'glm\' classes\n")}
 }
 
 
@@ -377,7 +378,7 @@ function(cand.set, modnames, newdata, second.ord = TRUE,
     class(Mod.pred.list) <- c("modavgpred", "list")
     return(Mod.pred.list)
     
-  } else {stop("This function is only appropriate with \'lme\' class\n")}
+  } else {stop("\nThis function is only appropriate with \'lme\' class\n")}
 }
 
 
@@ -385,7 +386,7 @@ function(cand.set, modnames, newdata, second.ord = TRUE,
 modavgpred.mer <- function(cand.set, modnames, newdata, type = "response", c.hat = 1, second.ord = TRUE,
                            nobs = NULL, uncond.se = "revised") {
   ##newdata is data frame with exact structure of the original data frame (same variable names and type)
-  if(c.hat != 1) {warning("This function only allows \'c.hat = 1\' for \'mer\' class objects\n")}
+  if(c.hat != 1) {warning("\nThis function only allows \'c.hat = 1\' for \'mer\' class objects\n")}
 
   ##extract classes
   mod.class <- unlist(lapply(X=cand.set, FUN=class))
@@ -396,12 +397,12 @@ modavgpred.mer <- function(cand.set, modnames, newdata, type = "response", c.hat
   if(identical(type, "link")) {
     link.list <- unlist(lapply(X = cand.set, FUN = function(i) fam.link.mer(i)$link))
     check.link <- unique(link.list)
-    if(length(check.link) > 1) stop(cat("\nIt is not appropriate to compute a model-averaged beta estimate\n",
-                                        "from models using different link functions\n"))
+    if(length(check.link) > 1) stop("\nIt is not appropriate to compute a model-averaged beta estimate\n",
+                                        "from models using different link functions\n")
   }
 
  
-  if(!identical(check.class, "mer")) {stop("This function is only appropriate with \'mer\' classes\n")}
+  if(!identical(check.class, "mer")) {stop("\nThis function is only appropriate with \'mer\' classes\n")}
 
        
   ##determine number of observations in data set
@@ -602,7 +603,7 @@ function(cand.set, modnames, newdata, second.ord = TRUE,
     class(Mod.pred.list) <- c("modavgpred", "list")
     return(Mod.pred.list)
     
-  } else {stop("This function is only appropriate with \'gls\' class\n")}
+  } else {stop("\nThis function is only appropriate with \'gls\' class\n")}
 }
 
 
